==> rhpam-7.13.0-sources.zip: rhba-7.13.0.GA-src/org.drools-drools-7.67.0.Final-7.13.0/drools-core/src/main/java/org/drools/core/reteoo/ObjectSinkNode.java <==
/*
 * Copyright 2005 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.drools.core.reteoo;

import org.drools.core.common.RuleBasePartitionId;

/**
 * Items placed in a <code>LinkedList<code> must implement this interface .
 * 
 * @see LeftTupleSinkNodeList
 */
public interface ObjectSinkNode
    extends
    ObjectSink {

    /**
     * Returns the next node
     * @return
     *      The next LinkedListNode
     */

    ObjectSinkNode getNextObjectSinkNode();

    /**
     * Sets the next node 
     * @param next
     *      The next LinkedListNode
     */
    void setNextObjectSinkNode(ObjectSinkNode next);

    /**
     * Returns the previous node
     * @return
     *      The previous LinkedListNode
     */
    ObjectSinkNode getPreviousObjectSinkNode();

    /**
     * Sets the previous node 
     * @param previous
     *      The previous LinkedListNode
     */
    void setPreviousObjectSinkNode(ObjectSinkNode previous);

    void setPartitionIdWithSinks( RuleBasePartitionId partitionId );
}

==> rhpam-7.13.5-sources.zip: rhba-7.13.5.GA-src/org.drools-drools-7.67.0.Final-7.13.5/drools-core/src/main/java/org/drools/core/reteoo/ObjectSinkNode.java <==
/*
 * Copyright 2005 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.drools.core.reteoo;

import org.drools.core.common.RuleBasePartitionId;

/**
 * Items placed in a <code>LinkedList<code> must implement this interface .
 * 
 * @see LeftTupleSinkNodeList
 */
public interface ObjectSinkNode
    extends
    ObjectSink {

    // Avoid secondary super cache invalidation by testing for abstract classes first
    // Then interfaces
    // See: https://issues.redhat.com/browse/DROOLS-7521
    static ObjectSinkNode getObjectSinkNode(Object sinkObject) {
        if(sinkObject instanceof AccumulateNode) {
            return (AccumulateNode) sinkObject;
        } else if(sinkObject instanceof LeftInputAdapterNode) {
            return (LeftInputAdapterNode) sinkObject;
        } else if(sinkObject instanceof WindowNode) {
            return (WindowNode) sinkObject;
        } else if (sinkObject instanceof BetaNode) {
            return (BetaNode) sinkObject;
        } else if (sinkObject instanceof AlphaNode) {
            return (AlphaNode) sinkObject;
        } else {
            return (ObjectSinkNode) sinkObject;
        }
    }

    /**
     * Returns the next node
     * @return
     *      The next LinkedListNode
     */

    ObjectSinkNode getNextObjectSinkNode();

    /**
     * Sets the next node 
     * @param next
     *      The next LinkedListNode
     */
    void setNextObjectSinkNode(ObjectSinkNode next);

    /**
     * Returns the previous node
     * @return
     *      The previous LinkedListNode
     */
    ObjectSinkNode getPreviousObjectSinkNode();

    /**
     * Sets the previous node 
     * @param previous
     *      The previous LinkedListNode
     */
    void setPreviousObjectSinkNode(ObjectSinkNode previous);

    void setPartitionIdWithSinks( RuleBasePartitionId partitionId );
}
